@@ -96,7 +96,7 @@ class Profile(object):
     def usable_django_model(cls):
         if cls.django_profile_model:
             if all(cls.django_connection_tuple):
-                if cls.django_connection_tuple[0] and not cls.django_connection_tuple[0].is_usable():
+                if cls.django_connection_tuple[0].connection and not cls.django_connection_tuple[0].is_usable():
                     del cls.django_connection_tuple[1]._connections.default
                 return cls.django_profile_model
             else:
